@@ -1,14 +1,14 @@
 b'This module needs Python 2.6 or later.'
 
 # Special variables #
-__version__ = '1.1.0'
+__version__ = '1.2.0'
 __all__ = ['load', 'new', 'convert']
 
 # Other variables #
 formats = ('sql', 'bed', 'wig', 'gff', 'gtf', 'bedgraph', 'bigwig', 'gzip', 'sga')
 
 # Built-in modules #
-import os, re, sqlite3, json
+import os, re, sqlite3
 from itertools import imap
 
 # Internal modules #
@@ -21,11 +21,13 @@ from track.common import check_path, check_file, empty_file, empty_sql_file, tem
 from track.common import JournaledDict, natural_sort, int_to_roman, roman_to_int
 from track.common import Color, pick_iterator_elements, get_next_item, is_gzip
 from track.common import if_url_then_get_url
-from track.genomes import Assembly
 
 # Compiled modules #
 from track.pyrow import SuperRow
 
+# Extra modules #
+from genomes import Assembly
+
 # Constants #
 special_tables = ('attributes', 'chrNames', 'types')
 minimum_fields = ('start', 'end')
@@ -340,7 +342,7 @@ class Track(object):
                 if 'score' in self._get_fields_of_table(ch):
                     self._cursor.execute("CREATE INDEX if not exists '" + ch + "_score_idx' on '" + ch + "' (score)")
                 if 'name' in self._get_fields_of_table(ch):
-                    self._cursor.execute("CREATE INDEX if not exists '" + ch + "_name_idx' on '" +  ch + "' (name)")
+                    self._cursor.execute("CREATE INDEX if not exists '" + ch + "_name_idx' on '" + ch + "' (name)")
         except sqlite3.OperationalError as err:
             message = "The index creation on the track '%s' failed with the following error: %s"
             raise Exception(message % (self.path, err))
@@ -683,7 +685,7 @@ class Track(object):
             # Drop all the columns #
             names = ','.join(['"' + f + '"' for f in new_fields])
             types = ','.join(['"' + f + '"' + ' ' + sql_field_types.get(f, 'text') for f in new_fields])
-            custom_sql_script= sql_script % dict(chrom=chrom, names=names, types=types)
+            custom_sql_script = sql_script % dict(chrom=chrom, names=names, types=types)
             self._cursor.executescript(custom_sql_script)
 
     #-----------------------------------------------------------------------------#
@@ -757,7 +759,7 @@ class Track(object):
         # A example final SQL string generated by this function is:
         # SELECT * from ("chrI","chrII","chrIII") WHERE gene_id like '%3%' AND gene_name like '%YCCA3%'
         conditions = []
-        if fields is None :
+        if fields is None:
             fields = self.fields
         # Generate condition #
         for k,v in query_dict.items():
@@ -790,7 +792,7 @@ class Track(object):
         if table_name is not None: fields = self.fields
         else:                      fields = self._get_fields_of_table(table_name)
         for name in synonyms:
-            if name in self.fields: return name
+            if name in fields: return name
         return ''
 
     #-----------------------------------------------------------------------------#
@@ -910,7 +912,7 @@ class Track(object):
 
             import track
             with track.new('tmp/track.sql') as t:
-                scores = t.get_score_vector('chr1')
+                scores = t.get_partial_score_vector('chr1', 100, 200)
         """
         # Check chromosome existence #
         if chromosome not in self: return
@@ -1122,7 +1124,7 @@ class Track(object):
 
     @property
     def assembly(self):
-        """Giving an assembly to your track is optional. However, if you set this variable for your track, you should input a valid assembly name such as 'sacCer2'. Doing so will set the *chrmeta* attribute and rename all the chromosome to their canonical names if a correspondence is found. You can also call ``guess_assembly()``. This attribute is also stored inside the *info* dictionary.
+        """Giving an assembly to your track is optional. However, if you set this variable for your track, you should input a valid assembly name such as 'sacCer2'. Doing so will set the *chrmeta* attribute and rename all the chromosome to their canonical names if a correspondence is found. This attribute is also stored inside the *info* dictionary.
 
         ::
 
@@ -1147,46 +1149,6 @@ class Track(object):
         # Add the chrmeta #
         self.chrmeta = assembly.chrmeta
 
-    #-----------------------------------------------------------------------------#
-    def aggregated_read(self, selection, base_fields, order_by=None):
-        """
-        Read the track with the *base_fields*, and aggregate all supplementary fields
-        found in a single string.
-
-        :param selection: The **selection** argument is passed to the **read** function.
-        :type selection: list
-        :param base_fields: the columns you don't want to aggregate.
-        :type base_fields: list
-        :param order_by: The **order_by** argument is passed to the **read** function.
-        :type order_by: list
-
-        :returns: a generator object yielding rows.
-
-        ::
-
-            >> import track
-            >> t = track.load('tmp/track.sql')
-            >> t.fields
-            ['start', 'stop', 'score', 'name', 'type', 'strand']
-            >> for feature in t.read('chr1'): print feature
-            [1,  10, 2.2, 'tc36', 'transcript', '+']
-            [1,  10, 3.4, 'tc36', 'transcript', '-']
-            [11, 12, 3.4, 'tc37', 'transcript', '+']
-            >> data = t.aggregated_read('chr1', ('start', 'stop', 'score'))
-            >> for feature in data: print feature
-            [1,  10, 2.2, "{name :'tc36', type:'transcript', strand:'+'}"]
-            [1,  10, 3.4, "{name :'tc36', type:'transcript', strand:'-'}"]
-            [11, 12, 3.4, "{name :'tc37', type:'transcript', strand:'+'}"]
-        """
-        base_fields = tuple(base_fields)
-        track_fields = self.fields
-        supplementary_fields = tuple(set(track_fields) - set(base_fields))
-        blen = len(base_fields)
-        ll = range(blen)
-        for feature in self.read(selection, base_fields + supplementary_fields, order=order_by):
-            d = [{field : feature[field]} for field in supplementary_fields if field in feature.keys()]
-            yield [feature[i] for i in ll] + [json.dumps(d)]
-
 ################################################################################
 class FeatureStream(object):
     """Contains an iterator yielding features and an extra
