@@ -74,9 +74,7 @@ def check_file(path):
 
 #------------------------------------------------------------------------------#
 def check_executable(tool_name):
-    """
-    Raises an exception if the executable *tool_name* is not found.
-    """
+    """Raises an exception if the executable *tool_name* is not found."""
     import subprocess
     try:
         subprocess.Popen([tool_name], stderr=subprocess.PIPE)
@@ -316,7 +314,21 @@ def natural_sort(item):
         except ValueError: return s
     return map(try_int, re.findall(r'(\d+|\D+)', item))
 
-###############################################################################
+#------------------------------------------------------------------------------#
+def andify_strings(list_of_strings):
+    """
+    Given a list of strings will join them with commas
+    and a final "and" word.
+
+    >>> andify_strings(['Apples', 'Oranges', 'Mangos'])
+    'Apples, Oranges and Mangos'
+    """
+    result = ', '.join(list_of_strings)
+    comma_index = result.rfind(',')
+    if comma_index > -1: result = result[:comma_index] + ' and' + result[comma_index+1:]
+    return result
+
+#------------------------------------------------------------------------------#
 def collapse(method, collection):
     """
     Collapse lists in specific ways.
@@ -432,6 +444,16 @@ def profile_it(command):
     os.remove(result_file)
     return results
 
+#------------------------------------------------------------------------------#
+def import_module(name):
+    """
+    Import a module that given it's name
+    and return that module.
+    """
+    __import__(name)
+    import sys
+    return sys.modules[name]
+
 ############################## CLASSES #########################################
 class Color:
     """Shortcuts for the ANSI escape sequences to control
@@ -615,17 +637,15 @@ class JournaledDict(object):
         self.data = d
 
 #------------------------------------------------------------------------------#
-class Timer:
-    """Times a given code block. Use it like this:
-
-            with Timer('my batch process'): batch_benchmark(args)
+class Timer(object):
+    """Time a given code block. Use it like this::
 
+            with Timer() as t: cool_benchmark(args)
+            print t.total_time
     """
 
-    def __init__(self, name=None, entries=1):
+    def __init__(self):
         import timeit
-        self.name = name
-        self.entries = entries
         self.timer = timeit.default_timer
 
     def __enter__(self):
@@ -634,34 +654,67 @@ class Timer:
 
     def __exit__(self, *args):
         self.end = self.timer()
-        total_time = self.end - self.start
-        entry_time = (1000000*total_time / self.entries)
-        line1 = "%.6f seconds for %s" % (total_time, self.name or 'Unnamed')
-        line2 = "(%.3f usec per entry)" % entry_time
-        print line1, line2
+        self.total_time = self.end - self.start
 
-############################## DECORATORS #####################################
-def property_cached(f):
-    """Decorator for properties evaluated only once.
-    It can be used to created a cached property like this::
-
-        class Employee(object):
-            @property_cached
-            def salary(self):
-                return 8000
-
-        bob = Employee()
-        print bob.salary
+#------------------------------------------------------------------------------#
+class Path(object):
     """
-    def get_method(self):
-        try:
-            return self.__cache__[f]
-        except AttributeError:
-            self.__cache__ = {}
-            x = self.__cache__[f] = f(self)
-            return x
-        except KeyError:
-            x = self.__cache__[f] = f(self)
-            return x
-    get_method.__doc__ = f.__doc__
-    return property(get_method)
+    Easy access to the to functions provided by the os.path module
+    Use it like this::
+
+        path = path("tmp/images/lena.png")
+        print path.extension
+        print path.filename
+        print path.directory
+    """
+
+    def __init__(self, path):
+        import os
+        self.path = path
+        self.extension = os.path.splitext(path)[0]
+        self.directory = os.path.dirname(path) + '/'
+        self.filename = os.path.splitext(os.path.basename(path))[0]
+
+    def __repr__(self):
+        return self.path
+
+#------------------------------------------------------------------------------#
+class Filesize(object):
+    """
+    Container for a size in bytes with a human readable representation
+    Use it like this::
+
+        >>> size = Filesize(123123123)
+        >>> print size
+        117.4 MB
+    """
+
+    chunk = 1024
+    units = ['bytes', 'KB', 'MB', 'GB', 'TB', 'PB']
+    precisions = [0, 0, 1, 2, 2, 2]
+
+    def __init__(self, value):
+        import os
+        if isinstance(value, int): self.size = value
+        else: self.size = os.path.getsize(str(value))
+
+    def __int__(self):
+        return self.size
+
+    def __float__(self):
+        return float(int(self))
+
+    def __repr__(self):
+        if self.size == 0: return '0 bytes'
+        from math import log
+        unit = self.units[min(int(log(self.size, self.chunk)), len(self.units) - 1)]
+        return self.format(unit)
+
+    def format(self, unit):
+        if unit not in self.units: raise Exception("Not a valid file size unit: %s" % unit)
+        if self.size == 1 and unit == 'bytes': return '1 byte'
+        exponent = self.units.index(unit)
+        quotient = float(self.size) / self.chunk**exponent
+        precision = self.precisions[exponent]
+        format_string = '{0:.%sf} {1}' % (precision)
+        return format_string.format(quotient, unit)
